/**
 * Copyright © 2015-2020 <a href="http://www.jeeplus.org/">JeePlus</a> All rights reserved.
 */
package com.jeeplus.modules.deductionshowdetails.mapper;

import com.jeeplus.modules.deductionshowdetails.entity.*;
import org.springframework.stereotype.Repository;
import com.jeeplus.core.persistence.BaseMapper;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

/**
 * DeductionShowDetailsMAPPER接口
 * @author 邱悦
 * @version 2022-01-02
 */
@Mapper
@Repository
public interface DeductionShowDetailsMapper extends BaseMapper<DeductionShowDetails> {
    List<SiteSafety> findSiteSafetyList(SiteSafety siteSafety);

    List<SiteQuality> findSiteQualityList(SiteQuality siteQuality);

    List<CostCompletion> findCostCompletionList(CostCompletion costCompletion);

    List<QualityCivilized> findQualityCivilizedList(QualityCivilized qualityCivilized);

    List<OtherPoints> findOtherPointsList(OtherPoints otherPoints);

    void deleteDetails(String id);

    String getName(String id);
}